@@ -12,7 +12,7 @@ DEFAULT_REMOVE = ["abstract", "annote",
                   #"comments", "comment",
                   "date-added", "date-modified", 
                   "file",
-                  "keyword", "keywords", 
+                  #"keyword", "keywords", 
                   "owner",
                   "timestamp"]
 
@@ -32,6 +32,8 @@ def get_arg_parser():
                         help="If this is set, the IDs of the bib entries are replaced by a fixed scheme")
     parser_modern.add_argument("--arxiv", action="store_true",
                         help="If this is set, the primaryClasses are downloaded for arXiv preprints. Requires an eprint field in the entry")
+    parser_modern.add_argument("--shield_title", action="store_true",
+                        help="If this is set, the title field will be surrounded by curly brackets.")
     parser_modern.add_argument("-v", "--verbose", action="count", default=0, help="Verbosity level. -v is info and -vv is debug")
     parser_modern.add_argument("-o", "--output", help="Output file for the new bib entries. If not specified, it will be the input file with a 'clean-' prefix.")
     parser_modern.add_argument("bib_file")
